nbxmpp.dispatcher_nb.BOSHDispatcher

Package nbxmpp :: Module dispatcher_nb :: Class BOSHDispatcher |
[hide private]
[frames] | no frames]

# Class BOSHDispatcher

source code

Instance Methods | [hide private]
PlugIn(self, owner, after_SASL=False, old_features=None) Attach to owner and register ourself and our _exported_methods in it. If defined by a subclass, call self.plugin(owner) to execute hook code after plugging | source code
StreamInit(self) Send an initial stream header | source code
StreamTerminate(self) Send a stream terminator | source code
ProcessNonBlocking(self, data=None) Check incoming stream for data waiting | source code
dispatch(self, stanza, session=None, direct=0) Main procedure that performs XMPP stanza recognition and calling apppropriate handlers for it. Called by simplexml | source code
Inherited from `XMPPDispatcher`: `Event`, `RegisterCycleHandler`, `RegisterDefaultHandler`, `RegisterEventHandler`, `RegisterHandler`, `RegisterHandlerOnce`, `RegisterNamespace`, `RegisterNamespaceHandler`, `RegisterProtocol`, `SendAndCallForResponse`, `SendAndWaitForResponse`, `UnregisterCycleHandler`, `UnregisterHandler`, `__init__`, `dumpHandlers`, `getAnID`, `plugin`, `plugout`, `replace_non_character`, `restoreHandlers`, `returnStanzaHandler`, `send` Inherited from `XMPPDispatcher` (private): `_WaitForData`, `_check_stream_start`, `_init` Inherited from `plugin.PlugIn`: `PlugOut`

Class Methods | [hide private]
Inherited from `plugin.PlugIn`: `get_instance`

Method Details | [hide private]

### PlugIn(self, owner, after_SASL=False, old_features=None) | source code
Attach to owner and register ourself and our _exported_methods in it. If defined by a subclass, call self.plugin(owner) to execute hook code after plugging Overrides: plugin.PlugIn.PlugIn (inherited documentation)

### StreamInit(self) | source code
Send an initial stream header Overrides: XMPPDispatcher.StreamInit

### StreamTerminate(self) | source code
Send a stream terminator

### ProcessNonBlocking(self, data=None) | source code
Check incoming stream for data waiting Parameters: `data` - data received from transports/IO sockets Returns: length of processed data if some data were processed; '0' string if no data were processed but link is alive; 0 (zero) if underlying connection is closed. Overrides: XMPPDispatcher.ProcessNonBlocking (inherited documentation)

### dispatch(self, stanza, session=None, direct=0) | source code
Main procedure that performs XMPP stanza recognition and calling apppropriate handlers for it. Called by simplexml Overrides: XMPPDispatcher.dispatch (inherited documentation)